@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: fsnotify
 version: 0.2.1
-id: fsnotify-0.2.1-85ca397d028f15e649c56651875fe6ce
-key: fsnot_1d5o3qoqGKl55eM4kXVrS9
+id: fsnotify-0.2.1-bd12a5c8c4da35887efffedad84659db
+key: fsnot_2PgImn35WXIENvOD2WG9bp
 license: BSD3
 maintainer: Greg Weber <greg@gregweber.info>, Roman Cheplyaka <roma@ro-che.info>
 homepage: https://github.com/haskell-fswatch/hfsnotify
@@ -24,7 +24,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/fsnotify-0.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/fsnotify-0.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/fsnotify-0.2.1
-hs-libraries: HSfsnotify-0.2.1-1d5o3qoqGKl55eM4kXVrS9
+hs-libraries: HSfsnotify-0.2.1-2PgImn35WXIENvOD2WG9bp
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -32,7 +32,7 @@ depends:
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hinotify-0.3.8.1-9263ea409ed8db1a0526fd40668cd381
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
 haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
